[Libreoffice-commits] core.git: 2 commits - cui/source extras/source include/svx svx/source
Libreoffice Gerrit user
logerrit at kemper.freedesktop.org
Wed Sep 19 15:21:06 UTC 2018
cui/source/dialogs/cuigrfflt.cxx | 5
cui/source/inc/backgrnd.hxx | 2
cui/source/inc/cuigrfflt.hxx | 4
cui/source/inc/cuitabarea.hxx | 2
cui/source/inc/measure.hxx | 2
cui/source/inc/textattr.hxx | 2
cui/source/inc/transfrm.hxx | 8 -
cui/source/tabpages/backgrnd.cxx | 2
extras/source/glade/libreoffice-catalog.xml.in | 3
include/svx/dlgctrl.hxx | 14 -
svx/source/accessibility/svxrectctaccessiblecontext.cxx | 122 ++++++++--------
svx/source/dialog/dlgctrl.cxx | 70 ++++-----
svx/source/inc/svxrectctaccessiblecontext.hxx | 20 +-
13 files changed, 126 insertions(+), 130 deletions(-)
New commits:
commit 8f4a399c7a6e7337d9be358a0611006b8fac6e40
Author: Caolán McNamara <caolanm at redhat.com>
AuthorDate: Tue Sep 18 15:07:23 2018 +0100
Commit: Caolán McNamara <caolanm at redhat.com>
CommitDate: Wed Sep 19 17:20:54 2018 +0200
drop unused cuilo-BackgroundPreview from catalog
Change-Id: Ib8707b29c44291fe18d86660d9bfaaed742afbd6
Reviewed-on: https://gerrit.libreoffice.org/60716
Tested-by: Jenkins
Reviewed-by: Caolán McNamara <caolanm at redhat.com>
Tested-by: Caolán McNamara <caolanm at redhat.com>
diff --git a/extras/source/glade/libreoffice-catalog.xml.in b/extras/source/glade/libreoffice-catalog.xml.in
index 3a4be0511258..0182cba12e5e 100644
--- a/extras/source/glade/libreoffice-catalog.xml.in
+++ b/extras/source/glade/libreoffice-catalog.xml.in
@@ -218,9 +218,6 @@
<glade-widget-class title="Document Preview Window" name="sdlo-SdDocPreviewWin"
generic-name="Document Preview Window" parent="GtkDrawingArea"
icon-name="widget-gtk-drawingarea"/>
- <glade-widget-class title="Background Preview" name="cuilo-BackgroundPreview"
- generic-name="Background Preview Window" parent="GtkDrawingArea"
- icon-name="widget-gtk-drawingarea"/>
<glade-widget-class title="Rectangle Preview" name="svxlo-SvxXRectPreview"
generic-name="Rectangle Preview Window" parent="GtkDrawingArea"
icon-name="widget-gtk-drawingarea"/>
commit 94da3afddd21ee1ca437132466995eb59a6bc05b
Author: Caolán McNamara <caolanm at redhat.com>
AuthorDate: Tue Sep 18 15:00:10 2018 +0100
Commit: Caolán McNamara <caolanm at redhat.com>
CommitDate: Wed Sep 19 17:20:42 2018 +0200
rename RectCtl back to SvxRectCtl
Change-Id: I4adde35b198d45fed09d837de5c1370d2a879f4b
Reviewed-on: https://gerrit.libreoffice.org/60715
Reviewed-by: Caolán McNamara <caolanm at redhat.com>
Tested-by: Caolán McNamara <caolanm at redhat.com>
diff --git a/cui/source/dialogs/cuigrfflt.cxx b/cui/source/dialogs/cuigrfflt.cxx
index 4850bd6927ca..9bc7dcf55cbf 100644
--- a/cui/source/dialogs/cuigrfflt.cxx
+++ b/cui/source/dialogs/cuigrfflt.cxx
@@ -396,12 +396,11 @@ Graphic GraphicFilterPoster::GetFilteredGraphic( const Graphic& rGraphic, double
return aRet;
}
-
void EmbossControl::MouseButtonDown( const MouseEvent& rEvt )
{
const RectPoint eOldRP = GetActualRP();
- RectCtl::MouseButtonDown( rEvt );
+ SvxRectCtl::MouseButtonDown( rEvt );
if( GetActualRP() != eOldRP )
maModifyHdl.Call( nullptr );
@@ -409,7 +408,7 @@ void EmbossControl::MouseButtonDown( const MouseEvent& rEvt )
void EmbossControl::SetDrawingArea(weld::DrawingArea* pDrawingArea)
{
- RectCtl::SetDrawingArea(pDrawingArea);
+ SvxRectCtl::SetDrawingArea(pDrawingArea);
Size aSize(pDrawingArea->get_ref_device().LogicToPixel(Size(77, 60), MapMode(MapUnit::MapAppFont)));
pDrawingArea->set_size_request(aSize.Width(), aSize.Height());
}
diff --git a/cui/source/inc/backgrnd.hxx b/cui/source/inc/backgrnd.hxx
index ebd62b0e8057..374409cb8a6f 100644
--- a/cui/source/inc/backgrnd.hxx
+++ b/cui/source/inc/backgrnd.hxx
@@ -92,7 +92,7 @@ private:
std::unique_ptr<SvxBackgroundTable_Impl> pTableBck_Impl;///< Items for Sw-Table must be corrected
std::unique_ptr<SvxBrushItem> pHighlighting;
- std::unique_ptr<RectCtl> m_xWndPosition;
+ std::unique_ptr<SvxRectCtl> m_xWndPosition;
std::unique_ptr<ColorValueSet> m_xBackgroundColorSet;
std::unique_ptr<BackgroundPreviewImpl> m_xPreview1;
std::unique_ptr<BackgroundPreviewImpl> m_xPreview2;
diff --git a/cui/source/inc/cuigrfflt.hxx b/cui/source/inc/cuigrfflt.hxx
index ae5169d4b8cc..b2e1c3d59ad4 100644
--- a/cui/source/inc/cuigrfflt.hxx
+++ b/cui/source/inc/cuigrfflt.hxx
@@ -158,7 +158,7 @@ public:
virtual Graphic GetFilteredGraphic( const Graphic& rGraphic, double fScaleX, double fScaleY ) override;
};
-class EmbossControl : public RectCtl
+class EmbossControl : public SvxRectCtl
{
private:
Link<LinkParamNone*, void> maModifyHdl;
@@ -166,7 +166,7 @@ private:
virtual void SetDrawingArea(weld::DrawingArea* pDrawingArea) override;
public:
EmbossControl()
- : RectCtl(nullptr)
+ : SvxRectCtl(nullptr)
{
}
diff --git a/cui/source/inc/cuitabarea.hxx b/cui/source/inc/cuitabarea.hxx
index c9d1a99bbc52..20f207aa9bb0 100644
--- a/cui/source/inc/cuitabarea.hxx
+++ b/cui/source/inc/cuitabarea.hxx
@@ -317,7 +317,7 @@ private:
SfxItemSet& m_rXFSet;
MapUnit m_ePoolUnit;
- RectCtl m_aCtlPosition;
+ SvxRectCtl m_aCtlPosition;
SvxXShadowPreview m_aCtlXRectPreview;
std::unique_ptr<weld::CheckButton> m_xTsbShowShadow;
std::unique_ptr<weld::Widget> m_xGridShadow;
diff --git a/cui/source/inc/measure.hxx b/cui/source/inc/measure.hxx
index a9af5c54ba7d..728814315783 100644
--- a/cui/source/inc/measure.hxx
+++ b/cui/source/inc/measure.hxx
@@ -40,7 +40,7 @@ private:
bool bPositionModified;
- RectCtl m_aCtlPosition;
+ SvxRectCtl m_aCtlPosition;
SvxXMeasurePreview m_aCtlPreview;
std::unique_ptr<weld::MetricSpinButton> m_xMtrFldLineDist;
std::unique_ptr<weld::MetricSpinButton> m_xMtrFldHelplineOverhang;
diff --git a/cui/source/inc/textattr.hxx b/cui/source/inc/textattr.hxx
index f0929e16109b..60bc9719887e 100644
--- a/cui/source/inc/textattr.hxx
+++ b/cui/source/inc/textattr.hxx
@@ -50,7 +50,7 @@ private:
bool bWordWrapTextEnabled;
bool bFitToSizeEnabled;
- RectCtl m_aCtlPosition;
+ SvxRectCtl m_aCtlPosition;
std::unique_ptr<weld::Widget> m_xDrawingText;
std::unique_ptr<weld::Widget> m_xCustomShapeText;
diff --git a/cui/source/inc/transfrm.hxx b/cui/source/inc/transfrm.hxx
index 95c137a2b051..0a9140e458dd 100644
--- a/cui/source/inc/transfrm.hxx
+++ b/cui/source/inc/transfrm.hxx
@@ -92,10 +92,10 @@ private:
// #i75273#
double mfOldWidth;
double mfOldHeight;
- RectPoint meRP;
+ RectPoint meRP;
- RectCtl m_aCtlPos;
- RectCtl m_aCtlSize;
+ SvxRectCtl m_aCtlPos;
+ SvxRectCtl m_aCtlSize;
// position
std::unique_ptr<weld::Widget> m_xFlPosition;
@@ -183,7 +183,7 @@ private:
FieldUnit eDlgUnit;
svx::SvxDialControl m_aCtlAngle;
- RectCtl m_aCtlRect;
+ SvxRectCtl m_aCtlRect;
std::unique_ptr<weld::Widget> m_xFlPosition;
std::unique_ptr<weld::MetricSpinButton> m_xMtrPosX;
diff --git a/cui/source/tabpages/backgrnd.cxx b/cui/source/tabpages/backgrnd.cxx
index e8b935ff98bd..c3c9a61850fd 100644
--- a/cui/source/tabpages/backgrnd.cxx
+++ b/cui/source/tabpages/backgrnd.cxx
@@ -297,7 +297,7 @@ SvxBackgroundTabPage::SvxBackgroundTabPage(TabPageParent pParent, const SfxItemS
, bCharBackColor(false)
, m_bColorSelected(false)
, pPageImpl(new SvxBackgroundPage_Impl)
- , m_xWndPosition(new RectCtl(this))
+ , m_xWndPosition(new SvxRectCtl(this))
, m_xBackgroundColorSet(new ColorValueSet(m_xBuilder->weld_scrolled_window("backgroundcolorsetwin")))
, m_xPreview1(new BackgroundPreviewImpl)
, m_xPreview2(new BackgroundPreviewImpl)
diff --git a/include/svx/dlgctrl.hxx b/include/svx/dlgctrl.hxx
index 3d9e1cb95fd5..c77811004000 100644
--- a/include/svx/dlgctrl.hxx
+++ b/include/svx/dlgctrl.hxx
@@ -76,10 +76,10 @@ namespace o3tl
template<> struct typed_flags<CTL_STATE> : is_typed_flags<CTL_STATE, 0x03> {};
}
-class RectCtlAccessibleContext;
+class SvxRectCtlAccessibleContext;
class SvxPixelCtlAccessible;
-class SAL_WARN_UNUSED SVX_DLLPUBLIC RectCtl : public weld::CustomWidgetController
+class SAL_WARN_UNUSED SVX_DLLPUBLIC SvxRectCtl : public weld::CustomWidgetController
{
private:
VclPtr<SvxTabPage> m_pPage;
@@ -89,11 +89,11 @@ private:
SVX_DLLPRIVATE BitmapEx& GetRectBitmap();
SVX_DLLPRIVATE void Resize_Impl(const Size& rSize);
- RectCtl(const RectCtl&) = delete;
- RectCtl& operator=(const RectCtl&) = delete;
+ SvxRectCtl(const SvxRectCtl&) = delete;
+ SvxRectCtl& operator=(const SvxRectCtl&) = delete;
protected:
- rtl::Reference<RectCtlAccessibleContext> pAccContext;
+ rtl::Reference<SvxRectCtlAccessibleContext> pAccContext;
sal_uInt16 nBorderWidth;
Point aPtLT, aPtMT, aPtRT;
Point aPtLM, aPtMM, aPtRM;
@@ -111,9 +111,9 @@ protected:
Point GetApproxLogPtFromPixPt( const Point& rRoughPixelPoint ) const;
public:
- RectCtl(SvxTabPage* pPage, RectPoint eRpt = RectPoint::MM, sal_uInt16 nBorder = 200);
+ SvxRectCtl(SvxTabPage* pPage, RectPoint eRpt = RectPoint::MM, sal_uInt16 nBorder = 200);
void SetControlSettings(RectPoint eRpt, sal_uInt16 nBorder);
- virtual ~RectCtl() override;
+ virtual ~SvxRectCtl() override;
virtual void Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle&) override;
virtual void Resize() override;
diff --git a/svx/source/accessibility/svxrectctaccessiblecontext.cxx b/svx/source/accessibility/svxrectctaccessiblecontext.cxx
index 106f639a9bbf..ffad961ec939 100644
--- a/svx/source/accessibility/svxrectctaccessiblecontext.cxx
+++ b/svx/source/accessibility/svxrectctaccessiblecontext.cxx
@@ -98,7 +98,7 @@ static long PointToIndex( RectPoint ePoint )
return nRet;
}
-RectCtlAccessibleContext::RectCtlAccessibleContext(RectCtl* pRepr)
+SvxRectCtlAccessibleContext::SvxRectCtlAccessibleContext(SvxRectCtl* pRepr)
: mpRepr(pRepr)
, mnSelectedChild(NOCHILDSELECTED)
{
@@ -111,15 +111,15 @@ RectCtlAccessibleContext::RectCtlAccessibleContext(RectCtl* pRepr)
mvChildren.resize(MAX_NUM_OF_CHILDREN);
}
-RectCtlAccessibleContext::~RectCtlAccessibleContext()
+SvxRectCtlAccessibleContext::~SvxRectCtlAccessibleContext()
{
ensureDisposed();
}
-IMPLEMENT_FORWARD_XINTERFACE2( RectCtlAccessibleContext, OAccessibleSelectionHelper, OAccessibleHelper_Base )
-IMPLEMENT_FORWARD_XTYPEPROVIDER2( RectCtlAccessibleContext, OAccessibleSelectionHelper, OAccessibleHelper_Base )
+IMPLEMENT_FORWARD_XINTERFACE2( SvxRectCtlAccessibleContext, OAccessibleSelectionHelper, OAccessibleHelper_Base )
+IMPLEMENT_FORWARD_XTYPEPROVIDER2( SvxRectCtlAccessibleContext, OAccessibleSelectionHelper, OAccessibleHelper_Base )
-Reference< XAccessible > SAL_CALL RectCtlAccessibleContext::getAccessibleAtPoint( const awt::Point& rPoint )
+Reference< XAccessible > SAL_CALL SvxRectCtlAccessibleContext::getAccessibleAtPoint( const awt::Point& rPoint )
{
::osl::MutexGuard aGuard( m_aMutex );
@@ -134,14 +134,14 @@ Reference< XAccessible > SAL_CALL RectCtlAccessibleContext::getAccessibleAtPoint
}
// XAccessibleContext
-sal_Int32 SAL_CALL RectCtlAccessibleContext::getAccessibleChildCount()
+sal_Int32 SAL_CALL SvxRectCtlAccessibleContext::getAccessibleChildCount()
{
::osl::MutexGuard aGuard( m_aMutex );
- return RectCtl::NO_CHILDREN;
+ return SvxRectCtl::NO_CHILDREN;
}
-Reference< XAccessible > SAL_CALL RectCtlAccessibleContext::getAccessibleChild( sal_Int32 nIndex )
+Reference< XAccessible > SAL_CALL SvxRectCtlAccessibleContext::getAccessibleChild( sal_Int32 nIndex )
{
checkChildIndex( nIndex );
@@ -162,7 +162,7 @@ Reference< XAccessible > SAL_CALL RectCtlAccessibleContext::getAccessibleChild(
tools::Rectangle aFocusRect( mpRepr->CalculateFocusRectangle( p->ePoint ) );
- RectCtlChildAccessibleContext* pChild = new RectCtlChildAccessibleContext(this, aName,
+ SvxRectCtlChildAccessibleContext* pChild = new SvxRectCtlChildAccessibleContext(this, aName,
aDescr, aFocusRect, nIndex );
mvChildren[ nIndex ] = pChild;
xChild = pChild;
@@ -176,7 +176,7 @@ Reference< XAccessible > SAL_CALL RectCtlAccessibleContext::getAccessibleChild(
return xChild;
}
-Reference< XAccessible > SAL_CALL RectCtlAccessibleContext::getAccessibleParent()
+Reference< XAccessible > SAL_CALL SvxRectCtlAccessibleContext::getAccessibleParent()
{
::osl::MutexGuard aGuard( m_aMutex );
if (mpRepr)
@@ -184,18 +184,18 @@ Reference< XAccessible > SAL_CALL RectCtlAccessibleContext::getAccessibleParent(
return uno::Reference<css::accessibility::XAccessible>();
}
-sal_Int16 SAL_CALL RectCtlAccessibleContext::getAccessibleRole()
+sal_Int16 SAL_CALL SvxRectCtlAccessibleContext::getAccessibleRole()
{
return AccessibleRole::PANEL;
}
-OUString SAL_CALL RectCtlAccessibleContext::getAccessibleDescription()
+OUString SAL_CALL SvxRectCtlAccessibleContext::getAccessibleDescription()
{
::osl::MutexGuard aGuard( m_aMutex );
return msDescription + " Please use arrow key to selection.";
}
-OUString SAL_CALL RectCtlAccessibleContext::getAccessibleName()
+OUString SAL_CALL SvxRectCtlAccessibleContext::getAccessibleName()
{
::osl::MutexGuard aGuard( m_aMutex );
return msName;
@@ -204,7 +204,7 @@ OUString SAL_CALL RectCtlAccessibleContext::getAccessibleName()
/** Return empty reference to indicate that the relation set is not
supported.
*/
-Reference< XAccessibleRelationSet > SAL_CALL RectCtlAccessibleContext::getAccessibleRelationSet()
+Reference< XAccessibleRelationSet > SAL_CALL SvxRectCtlAccessibleContext::getAccessibleRelationSet()
{
::osl::MutexGuard aGuard( m_aMutex );
if (mpRepr)
@@ -212,7 +212,7 @@ Reference< XAccessibleRelationSet > SAL_CALL RectCtlAccessibleContext::getAccess
return uno::Reference<css::accessibility::XAccessibleRelationSet>();
}
-Reference< XAccessibleStateSet > SAL_CALL RectCtlAccessibleContext::getAccessibleStateSet()
+Reference< XAccessibleStateSet > SAL_CALL SvxRectCtlAccessibleContext::getAccessibleStateSet()
{
::osl::MutexGuard aGuard( m_aMutex );
utl::AccessibleStateSetHelper* pStateSetHelper = new utl::AccessibleStateSetHelper;
@@ -236,7 +236,7 @@ Reference< XAccessibleStateSet > SAL_CALL RectCtlAccessibleContext::getAccessibl
return pStateSetHelper;
}
-void SAL_CALL RectCtlAccessibleContext::grabFocus()
+void SAL_CALL SvxRectCtlAccessibleContext::grabFocus()
{
::SolarMutexGuard aSolarGuard;
::osl::MutexGuard aGuard( m_aMutex );
@@ -245,28 +245,28 @@ void SAL_CALL RectCtlAccessibleContext::grabFocus()
mpRepr->GrabFocus();
}
-sal_Int32 RectCtlAccessibleContext::getForeground()
+sal_Int32 SvxRectCtlAccessibleContext::getForeground()
{
::SolarMutexGuard aSolarGuard;
::osl::MutexGuard aGuard( m_aMutex );
- //see RectCtl::Paint
+ //see SvxRectCtl::Paint
const StyleSettings& rStyles = Application::GetSettings().GetStyleSettings();
return sal_Int32(rStyles.GetLabelTextColor());
}
-sal_Int32 RectCtlAccessibleContext::getBackground( )
+sal_Int32 SvxRectCtlAccessibleContext::getBackground( )
{
::SolarMutexGuard aSolarGuard;
::osl::MutexGuard aGuard( m_aMutex );
- //see RectCtl::Paint
+ //see SvxRectCtl::Paint
const StyleSettings& rStyles = Application::GetSettings().GetStyleSettings();
return sal_Int32(rStyles.GetDialogColor());
}
// XAccessibleSelection
-void RectCtlAccessibleContext::implSelect(sal_Int32 nIndex, bool bSelect)
+void SvxRectCtlAccessibleContext::implSelect(sal_Int32 nIndex, bool bSelect)
{
::SolarMutexGuard aSolarGuard;
@@ -276,7 +276,7 @@ void RectCtlAccessibleContext::implSelect(sal_Int32 nIndex, bool bSelect)
const ChildIndexToPointData* pData = IndexToPoint( nIndex );
- DBG_ASSERT(pData, "RectCtlAccessibleContext::selectAccessibleChild(): this is an impossible state! Or at least should be...");
+ DBG_ASSERT(pData, "SvxRectCtlAccessibleContext::selectAccessibleChild(): this is an impossible state! Or at least should be...");
if (mpRepr)
{
@@ -287,12 +287,12 @@ void RectCtlAccessibleContext::implSelect(sal_Int32 nIndex, bool bSelect)
}
else
{
- SAL_WARN( "svx", "RectCtlAccessibleContext::clearAccessibleSelection() is not possible!" );
+ SAL_WARN( "svx", "SvxRectCtlAccessibleContext::clearAccessibleSelection() is not possible!" );
}
}
}
-bool RectCtlAccessibleContext::implIsSelected( sal_Int32 nIndex )
+bool SvxRectCtlAccessibleContext::implIsSelected( sal_Int32 nIndex )
{
::osl::MutexGuard aGuard( m_aMutex );
@@ -302,13 +302,13 @@ bool RectCtlAccessibleContext::implIsSelected( sal_Int32 nIndex )
}
// internals
-void RectCtlAccessibleContext::checkChildIndex( long nIndex )
+void SvxRectCtlAccessibleContext::checkChildIndex( long nIndex )
{
if( nIndex < 0 || nIndex >= getAccessibleChildCount() )
throw lang::IndexOutOfBoundsException();
}
-void RectCtlAccessibleContext::FireChildFocus( RectPoint eButton )
+void SvxRectCtlAccessibleContext::FireChildFocus( RectPoint eButton )
{
::osl::MutexGuard aGuard( m_aMutex );
long nNew = PointToIndex( eButton );
@@ -334,7 +334,7 @@ void RectCtlAccessibleContext::FireChildFocus( RectPoint eButton )
mnSelectedChild = NOCHILDSELECTED;
}
-void RectCtlAccessibleContext::selectChild( long nNew )
+void SvxRectCtlAccessibleContext::selectChild( long nNew )
{
::osl::MutexGuard aGuard( m_aMutex );
if( nNew != mnSelectedChild )
@@ -342,7 +342,7 @@ void RectCtlAccessibleContext::selectChild( long nNew )
long nNumOfChildren = getAccessibleChildCount();
if( nNew < nNumOfChildren )
{ // valid index
- RectCtlChildAccessibleContext* pChild;
+ SvxRectCtlChildAccessibleContext* pChild;
if( mnSelectedChild != NOCHILDSELECTED )
{ // deselect old selected child if one is selected
pChild = mvChildren[ mnSelectedChild ].get();
@@ -364,13 +364,13 @@ void RectCtlAccessibleContext::selectChild( long nNew )
}
}
-void RectCtlAccessibleContext::selectChild(RectPoint eButton )
+void SvxRectCtlAccessibleContext::selectChild(RectPoint eButton )
{
// no guard -> is done in next selectChild
selectChild(PointToIndex( eButton ));
}
-void SAL_CALL RectCtlAccessibleContext::disposing()
+void SAL_CALL SvxRectCtlAccessibleContext::disposing()
{
::osl::MutexGuard aGuard(m_aMutex);
OAccessibleSelectionHelper::disposing();
@@ -383,7 +383,7 @@ void SAL_CALL RectCtlAccessibleContext::disposing()
mpRepr = nullptr;
}
-awt::Rectangle RectCtlAccessibleContext::implGetBounds()
+awt::Rectangle SvxRectCtlAccessibleContext::implGetBounds()
{
::SolarMutexGuard aSolarGuard;
::osl::MutexGuard aGuard( m_aMutex );
@@ -404,7 +404,7 @@ awt::Rectangle RectCtlAccessibleContext::implGetBounds()
return aRet;
}
-RectCtlChildAccessibleContext::RectCtlChildAccessibleContext(
+SvxRectCtlChildAccessibleContext::SvxRectCtlChildAccessibleContext(
const Reference<XAccessible>& rxParent,
const OUString& rName,
const OUString& rDescription,
@@ -419,68 +419,68 @@ RectCtlChildAccessibleContext::RectCtlChildAccessibleContext(
{
}
-RectCtlChildAccessibleContext::~RectCtlChildAccessibleContext()
+SvxRectCtlChildAccessibleContext::~SvxRectCtlChildAccessibleContext()
{
ensureDisposed();
}
-Reference< XAccessible > SAL_CALL RectCtlChildAccessibleContext::getAccessibleAtPoint( const awt::Point& /*rPoint*/ )
+Reference< XAccessible > SAL_CALL SvxRectCtlChildAccessibleContext::getAccessibleAtPoint( const awt::Point& /*rPoint*/ )
{
return Reference< XAccessible >();
}
-void SAL_CALL RectCtlChildAccessibleContext::grabFocus()
+void SAL_CALL SvxRectCtlChildAccessibleContext::grabFocus()
{
}
-sal_Int32 RectCtlChildAccessibleContext::getForeground( )
+sal_Int32 SvxRectCtlChildAccessibleContext::getForeground( )
{
::SolarMutexGuard aSolarGuard;
::osl::MutexGuard aGuard( m_aMutex );
- //see RectCtl::Paint
+ //see SvxRectCtl::Paint
const StyleSettings& rStyles = Application::GetSettings().GetStyleSettings();
return sal_Int32(rStyles.GetLabelTextColor());
}
-sal_Int32 RectCtlChildAccessibleContext::getBackground( )
+sal_Int32 SvxRectCtlChildAccessibleContext::getBackground( )
{
::SolarMutexGuard aSolarGuard;
::osl::MutexGuard aGuard( m_aMutex );
- //see RectCtl::Paint
+ //see SvxRectCtl::Paint
const StyleSettings& rStyles = Application::GetSettings().GetStyleSettings();
return sal_Int32(rStyles.GetDialogColor());
}
// XAccessibleContext
-sal_Int32 SAL_CALL RectCtlChildAccessibleContext::getAccessibleChildCount()
+sal_Int32 SAL_CALL SvxRectCtlChildAccessibleContext::getAccessibleChildCount()
{
return 0;
}
-Reference< XAccessible > SAL_CALL RectCtlChildAccessibleContext::getAccessibleChild( sal_Int32 /*nIndex*/ )
+Reference< XAccessible > SAL_CALL SvxRectCtlChildAccessibleContext::getAccessibleChild( sal_Int32 /*nIndex*/ )
{
throw lang::IndexOutOfBoundsException();
}
-Reference< XAccessible > SAL_CALL RectCtlChildAccessibleContext::getAccessibleParent()
+Reference< XAccessible > SAL_CALL SvxRectCtlChildAccessibleContext::getAccessibleParent()
{
return mxParent;
}
-sal_Int16 SAL_CALL RectCtlChildAccessibleContext::getAccessibleRole()
+sal_Int16 SAL_CALL SvxRectCtlChildAccessibleContext::getAccessibleRole()
{
return AccessibleRole::RADIO_BUTTON;
}
-OUString SAL_CALL RectCtlChildAccessibleContext::getAccessibleDescription()
+OUString SAL_CALL SvxRectCtlChildAccessibleContext::getAccessibleDescription()
{
::osl::MutexGuard aGuard( m_aMutex );
return msDescription;
}
-OUString SAL_CALL RectCtlChildAccessibleContext::getAccessibleName()
+OUString SAL_CALL SvxRectCtlChildAccessibleContext::getAccessibleName()
{
::osl::MutexGuard aGuard( m_aMutex );
return msName;
@@ -489,7 +489,7 @@ OUString SAL_CALL RectCtlChildAccessibleContext::getAccessibleName()
/** Return empty reference to indicate that the relation set is not
supported.
*/
-Reference<XAccessibleRelationSet> SAL_CALL RectCtlChildAccessibleContext::getAccessibleRelationSet()
+Reference<XAccessibleRelationSet> SAL_CALL SvxRectCtlChildAccessibleContext::getAccessibleRelationSet()
{
utl::AccessibleRelationSetHelper* pRelationSetHelper = new utl::AccessibleRelationSetHelper;
uno::Reference< css::accessibility::XAccessibleRelationSet > xSet = pRelationSetHelper;
@@ -503,7 +503,7 @@ Reference<XAccessibleRelationSet> SAL_CALL RectCtlChildAccessibleContext::getAcc
return xSet;
}
-Reference< XAccessibleStateSet > SAL_CALL RectCtlChildAccessibleContext::getAccessibleStateSet()
+Reference< XAccessibleStateSet > SAL_CALL SvxRectCtlChildAccessibleContext::getAccessibleStateSet()
{
::osl::MutexGuard aGuard( m_aMutex );
utl::AccessibleStateSetHelper* pStateSetHelper = new utl::AccessibleStateSetHelper;
@@ -529,26 +529,26 @@ Reference< XAccessibleStateSet > SAL_CALL RectCtlChildAccessibleContext::getAcce
}
// XAccessibleValue
-Any SAL_CALL RectCtlChildAccessibleContext::getCurrentValue()
+Any SAL_CALL SvxRectCtlChildAccessibleContext::getCurrentValue()
{
Any aRet;
aRet <<= ( mbIsChecked? 1.0 : 0.0 );
return aRet;
}
-sal_Bool SAL_CALL RectCtlChildAccessibleContext::setCurrentValue( const Any& /*aNumber*/ )
+sal_Bool SAL_CALL SvxRectCtlChildAccessibleContext::setCurrentValue( const Any& /*aNumber*/ )
{
return false;
}
-Any SAL_CALL RectCtlChildAccessibleContext::getMaximumValue()
+Any SAL_CALL SvxRectCtlChildAccessibleContext::getMaximumValue()
{
Any aRet;
aRet <<= 1.0;
return aRet;
}
-Any SAL_CALL RectCtlChildAccessibleContext::getMinimumValue()
+Any SAL_CALL SvxRectCtlChildAccessibleContext::getMinimumValue()
{
Any aRet;
aRet <<= 0.0;
@@ -559,13 +559,13 @@ Any SAL_CALL RectCtlChildAccessibleContext::getMinimumValue()
// XAccessibleAction
-sal_Int32 RectCtlChildAccessibleContext::getAccessibleActionCount( )
+sal_Int32 SvxRectCtlChildAccessibleContext::getAccessibleActionCount( )
{
return 1;
}
-sal_Bool RectCtlChildAccessibleContext::doAccessibleAction ( sal_Int32 nIndex )
+sal_Bool SvxRectCtlChildAccessibleContext::doAccessibleAction ( sal_Int32 nIndex )
{
::osl::MutexGuard aGuard( m_aMutex );
@@ -580,7 +580,7 @@ sal_Bool RectCtlChildAccessibleContext::doAccessibleAction ( sal_Int32 nIndex )
}
-OUString RectCtlChildAccessibleContext::getAccessibleActionDescription ( sal_Int32 nIndex )
+OUString SvxRectCtlChildAccessibleContext::getAccessibleActionDescription ( sal_Int32 nIndex )
{
::osl::MutexGuard aGuard( m_aMutex );
@@ -591,7 +591,7 @@ OUString RectCtlChildAccessibleContext::getAccessibleActionDescription ( sal_Int
}
-Reference< XAccessibleKeyBinding > RectCtlChildAccessibleContext::getAccessibleActionKeyBinding( sal_Int32 nIndex )
+Reference< XAccessibleKeyBinding > SvxRectCtlChildAccessibleContext::getAccessibleActionKeyBinding( sal_Int32 nIndex )
{
::osl::MutexGuard aGuard( m_aMutex );
@@ -601,19 +601,19 @@ Reference< XAccessibleKeyBinding > RectCtlChildAccessibleContext::getAccessibleA
return Reference< XAccessibleKeyBinding >();
}
-void SAL_CALL RectCtlChildAccessibleContext::disposing()
+void SAL_CALL SvxRectCtlChildAccessibleContext::disposing()
{
OAccessibleComponentHelper::disposing();
mxParent.clear();
}
-awt::Rectangle RectCtlChildAccessibleContext::implGetBounds( )
+awt::Rectangle SvxRectCtlChildAccessibleContext::implGetBounds( )
{
// no guard necessary, because no one changes maBoundingBox after creating it
return AWTRectangle(maBoundingBox);
}
-void RectCtlChildAccessibleContext::setStateChecked( bool bChecked )
+void SvxRectCtlChildAccessibleContext::setStateChecked( bool bChecked )
{
if( mbIsChecked != bChecked )
{
@@ -633,7 +633,7 @@ void RectCtlChildAccessibleContext::setStateChecked( bool bChecked )
}
}
-void RectCtlChildAccessibleContext::FireFocusEvent()
+void SvxRectCtlChildAccessibleContext::FireFocusEvent()
{
Any aOld;
Any aNew;
@@ -641,7 +641,7 @@ void RectCtlChildAccessibleContext::FireFocusEvent()
NotifyAccessibleEvent(AccessibleEventId::STATE_CHANGED, aOld, aNew);
}
-IMPLEMENT_FORWARD_XINTERFACE2( RectCtlChildAccessibleContext, OAccessibleComponentHelper, OAccessibleHelper_Base_3 )
-IMPLEMENT_FORWARD_XTYPEPROVIDER2( RectCtlChildAccessibleContext, OAccessibleComponentHelper, OAccessibleHelper_Base_3 )
+IMPLEMENT_FORWARD_XINTERFACE2( SvxRectCtlChildAccessibleContext, OAccessibleComponentHelper, OAccessibleHelper_Base_3 )
+IMPLEMENT_FORWARD_XTYPEPROVIDER2( SvxRectCtlChildAccessibleContext, OAccessibleComponentHelper, OAccessibleHelper_Base_3 )
/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/svx/source/inc/svxrectctaccessiblecontext.hxx b/svx/source/inc/svxrectctaccessiblecontext.hxx
index f5648c3e319e..f40fc64c7762 100644
--- a/svx/source/inc/svxrectctaccessiblecontext.hxx
+++ b/svx/source/inc/svxrectctaccessiblecontext.hxx
@@ -57,18 +57,18 @@ namespace com { namespace sun { namespace star { namespace awt {
} } } }
namespace tools { class Rectangle; }
-class RectCtl;
-class RectCtlChildAccessibleContext;
+class SvxRectCtl;
+class SvxRectCtlChildAccessibleContext;
namespace vcl { class Window; }
typedef ::cppu::ImplHelper1<css::accessibility::XAccessible> OAccessibleHelper_Base;
-class RectCtlAccessibleContext final : public ::comphelper::OAccessibleSelectionHelper,
+class SvxRectCtlAccessibleContext final : public ::comphelper::OAccessibleSelectionHelper,
public OAccessibleHelper_Base
{
public:
// internal
- RectCtlAccessibleContext(RectCtl* pRepresentation);
+ SvxRectCtlAccessibleContext(SvxRectCtl* pRepresentation);
DECLARE_XINTERFACE( )
DECLARE_XTYPEPROVIDER( )
@@ -104,7 +104,7 @@ public:
void FireChildFocus( RectPoint eButton );
private:
- virtual ~RectCtlAccessibleContext() override;
+ virtual ~SvxRectCtlAccessibleContext() override;
// OCommonAccessibleSelection
// return if the specified child is visible => watch for special ChildIndexes (ACCESSIBLE_SELECTION_CHILD_xxx)
@@ -140,10 +140,10 @@ private:
OUString msName;
/// pointer to internal representation
- RectCtl* mpRepr;
+ SvxRectCtl* mpRepr;
/// array for all possible children
- std::vector<rtl::Reference<RectCtlChildAccessibleContext>> mvChildren;
+ std::vector<rtl::Reference<SvxRectCtlChildAccessibleContext>> mvChildren;
/// actual selected child
long mnSelectedChild;
@@ -154,11 +154,11 @@ typedef ::cppu::ImplHelper3 < css::accessibility::XAccessible,
css::accessibility::XAccessibleAction
> OAccessibleHelper_Base_3;
-class RectCtlChildAccessibleContext final : public ::comphelper::OAccessibleComponentHelper,
+class SvxRectCtlChildAccessibleContext final : public ::comphelper::OAccessibleComponentHelper,
public OAccessibleHelper_Base_3
{
public:
- RectCtlChildAccessibleContext(
+ SvxRectCtlChildAccessibleContext(
const css::uno::Reference< css::accessibility::XAccessible>& rxParent,
const OUString& rName, const OUString& rDescription,
const tools::Rectangle& rBoundingBox,
@@ -211,7 +211,7 @@ public:
void FireFocusEvent();
private:
- virtual ~RectCtlChildAccessibleContext() override;
+ virtual ~SvxRectCtlChildAccessibleContext() override;
virtual void SAL_CALL disposing() override;
More information about the Libreoffice-commits
mailing list
diff --git a/svx/source/dialog/dlgctrl.cxx b/svx/source/dialog/dlgctrl.cxx
index 9c94f493ce17..637ef4858949 100644
--- a/svx/source/dialog/dlgctrl.cxx
+++ b/svx/source/dialog/dlgctrl.cxx
@@ -60,7 +60,7 @@ using namespace ::com::sun::star::accessibility;
// Control for display and selection of the corner points and
// mid point of an object
-BitmapEx& RectCtl::GetRectBitmap()
+BitmapEx& SvxRectCtl::GetRectBitmap()
{
if( !pBitmap )
InitRectBitmap();
@@ -68,7 +68,7 @@ BitmapEx& RectCtl::GetRectBitmap()
return *pBitmap;
}
-RectCtl::RectCtl(SvxTabPage* pPage, RectPoint eRpt, sal_uInt16 nBorder)
+SvxRectCtl::SvxRectCtl(SvxTabPage* pPage, RectPoint eRpt, sal_uInt16 nBorder)
: m_pPage(pPage)
, nBorderWidth(Application::GetDefaultDevice()->LogicToPixel(Size(nBorder, 0), MapMode(MapUnit::Map100thMM)).Width())
, eRP(eRpt)
@@ -78,7 +78,7 @@ RectCtl::RectCtl(SvxTabPage* pPage, RectPoint eRpt, sal_uInt16 nBorder)
{
}
-void RectCtl::SetDrawingArea(weld::DrawingArea* pDrawingArea)
+void SvxRectCtl::SetDrawingArea(weld::DrawingArea* pDrawingArea)
{
CustomWidgetController::SetDrawingArea(pDrawingArea);
Size aSize(pDrawingArea->get_approximate_digit_width() * 25,
@@ -87,25 +87,25 @@ void RectCtl::SetDrawingArea(weld::DrawingArea* pDrawingArea)
Resize_Impl(aSize);
}
-void RectCtl::SetControlSettings(RectPoint eRpt, sal_uInt16 nBorder)
+void SvxRectCtl::SetControlSettings(RectPoint eRpt, sal_uInt16 nBorder)
{
nBorderWidth = Application::GetDefaultDevice()->LogicToPixel(Size(nBorder, 0), MapMode(MapUnit::Map100thMM)).Width();
eDefRP = eRpt;
Resize();
}
-RectCtl::~RectCtl()
+SvxRectCtl::~SvxRectCtl()
{
pBitmap.reset();
pAccContext.clear();
}
-void RectCtl::Resize()
+void SvxRectCtl::Resize()
{
Resize_Impl(GetOutputSizePixel());
}
-void RectCtl::Resize_Impl(const Size &rSize)
+void SvxRectCtl::Resize_Impl(const Size &rSize)
{
aPtLT = Point( 0 + nBorderWidth, 0 + nBorderWidth );
aPtMT = Point( rSize.Width() / 2, 0 + nBorderWidth );
@@ -123,7 +123,7 @@ void RectCtl::Resize_Impl(const Size &rSize)
StyleUpdated();
}
-void RectCtl::InitRectBitmap()
+void SvxRectCtl::InitRectBitmap()
{
pBitmap.reset();
@@ -170,13 +170,13 @@ void RectCtl::InitRectBitmap()
pBitmap->Replace( aColorAry1, aColorAry2, 7 );
}
-void RectCtl::StyleUpdated()
+void SvxRectCtl::StyleUpdated()
{
pBitmap.reset(); // forces new creating of bitmap
CustomWidgetController::StyleUpdated();
}
-void RectCtl::InitSettings(vcl::RenderContext& rRenderContext)
+void SvxRectCtl::InitSettings(vcl::RenderContext& rRenderContext)
{
svtools::ColorConfig aColorConfig;
Color aTextColor(aColorConfig.GetColorValue(svtools::FONTCOLOR).nColor);
@@ -187,9 +187,9 @@ void RectCtl::InitSettings(vcl::RenderContext& rRenderContext)
// The clicked rectangle (3 x 3) is determined and the parent (dialog)
// is notified that the item was changed
-void RectCtl::MouseButtonDown(const MouseEvent& rMEvt)
+void SvxRectCtl::MouseButtonDown(const MouseEvent& rMEvt)
{
// CompletelyDisabled() added to have a disabled state for RectCtl
if(!IsCompletelyDisabled())
{
aPtNew = GetApproxLogPtFromPixPt( rMEvt.GetPosPixel() );
@@ -201,9 +201,9 @@ void RectCtl::MouseButtonDown(const MouseEvent& rMEvt)
}
}
-bool RectCtl::KeyInput(const KeyEvent& rKeyEvt)
+bool SvxRectCtl::KeyInput(const KeyEvent& rKeyEvt)
{
// CompletelyDisabled() added to have a disabled state for RectCtl
if (IsCompletelyDisabled())
return false;
@@ -285,7 +285,7 @@ bool RectCtl::KeyInput(const KeyEvent& rKeyEvt)
}
// the control (rectangle with 9 circles)
-void RectCtl::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle&)
+void SvxRectCtl::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle&)
{
InitSettings(rRenderContext);
@@ -327,7 +327,7 @@ void RectCtl::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle&)
BitmapEx& rBitmap = GetRectBitmap();
// CompletelyDisabled() added to have a disabled state for RectCtl
if (IsCompletelyDisabled())
{
rRenderContext.DrawBitmap(aPtLT - aToCenter, aDstBtnSize, aBtnPnt3, aBtnSize, rBitmap.GetBitmap());
@@ -357,7 +357,7 @@ void RectCtl::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle&)
}
// draw active button, avoid center pos for angle
// CompletelyDisabled() added to have a disabled state for RectCtl
if (!IsCompletelyDisabled())
{
if (IsEnabled())
@@ -370,7 +370,7 @@ void RectCtl::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle&)
}
}
-tools::Rectangle RectCtl::GetFocusRect()
+tools::Rectangle SvxRectCtl::GetFocusRect()
{
tools::Rectangle aRet;
if (HasFocus())
@@ -380,7 +380,7 @@ tools::Rectangle RectCtl::GetFocusRect()
// Convert RectPoint Point
-const Point& RectCtl::GetPointFromRP( RectPoint _eRP) const
+const Point& SvxRectCtl::GetPointFromRP( RectPoint _eRP) const
{
switch( _eRP )
{
@@ -397,7 +397,7 @@ const Point& RectCtl::GetPointFromRP( RectPoint _eRP) const
return aPtMM; // default
}
-Point RectCtl::SetActualRPWithoutInvalidate( RectPoint eNewRP )
+Point SvxRectCtl::SetActualRPWithoutInvalidate( RectPoint eNewRP )
{
Point aPtLast = aPtNew;
aPtNew = GetPointFromRP( eNewRP );
@@ -418,7 +418,7 @@ Point RectCtl::SetActualRPWithoutInvalidate( RectPoint eNewRP )
return aPtLast;
}
-void RectCtl::GetFocus()
+void SvxRectCtl::GetFocus()
{
Invalidate();
@@ -429,12 +429,12 @@ void RectCtl::GetFocus()
}
}
-void RectCtl::LoseFocus()
+void SvxRectCtl::LoseFocus()
{
Invalidate();
}
-Point RectCtl::GetApproxLogPtFromPixPt( const Point& rPt ) const
+Point SvxRectCtl::GetApproxLogPtFromPixPt( const Point& rPt ) const
{
Point aPt = rPt;
long x;
@@ -472,7 +472,7 @@ Point RectCtl::GetApproxLogPtFromPixPt( const Point& rPt ) const
// Converts Point in RectPoint
-RectPoint RectCtl::GetRPFromPoint( Point aPt, bool bRTL ) const
+RectPoint SvxRectCtl::GetRPFromPoint( Point aPt, bool bRTL ) const
{
RectPoint rPoint = RectPoint::MM; // default
@@ -490,7 +490,7 @@ RectPoint RectCtl::GetRPFromPoint( Point aPt, bool bRTL ) const
// Resets to the original state of the control
-void RectCtl::Reset()
+void SvxRectCtl::Reset()
{
aPtNew = GetPointFromRP( eDefRP );
eRP = eDefRP;
@@ -500,7 +500,7 @@ void RectCtl::Reset()
// Returns the currently selected RectPoint
-void RectCtl::SetActualRP( RectPoint eNewRP )
+void SvxRectCtl::SetActualRP( RectPoint eNewRP )
{
SetActualRPWithoutInvalidate(eNewRP);
@@ -511,7 +511,7 @@ void RectCtl::SetActualRP( RectPoint eNewRP )
pAccContext->selectChild( eNewRP /* MT, bFireFocus */ );
}
-void RectCtl::SetState( CTL_STATE nState )
+void SvxRectCtl::SetState( CTL_STATE nState )
{
m_nState = nState;
@@ -531,13 +531,13 @@ void RectCtl::SetState( CTL_STATE nState )
m_pPage->PointChanged(GetDrawingArea(), eRP);
}
-tools::Rectangle RectCtl::CalculateFocusRectangle() const
+tools::Rectangle SvxRectCtl::CalculateFocusRectangle() const
{
Size aDstBtnSize(15, 15);
return tools::Rectangle( aPtNew - Point( aDstBtnSize.Width() >> 1, aDstBtnSize.Height() >> 1 ), aDstBtnSize );
}
-tools::Rectangle RectCtl::CalculateFocusRectangle( RectPoint eRectPoint ) const
+tools::Rectangle SvxRectCtl::CalculateFocusRectangle( RectPoint eRectPoint ) const
{
tools::Rectangle aRet;
RectPoint eOldRectPoint = GetActualRP();
@@ -546,7 +546,7 @@ tools::Rectangle RectCtl::CalculateFocusRectangle( RectPoint eRectPoint ) const
aRet = CalculateFocusRectangle();
else
{
- RectCtl* pThis = const_cast<RectCtl*>(this);
+ SvxRectCtl* pThis = const_cast<SvxRectCtl*>(this);
pThis->SetActualRPWithoutInvalidate( eRectPoint ); // no invalidation because it's only temporary!
aRet = CalculateFocusRectangle();
@@ -557,19 +557,19 @@ tools::Rectangle RectCtl::CalculateFocusRectangle( RectPoint eRectPoint ) const
return aRet;
}
-Reference< XAccessible > RectCtl::CreateAccessible()
+Reference< XAccessible > SvxRectCtl::CreateAccessible()
{
- pAccContext = new RectCtlAccessibleContext(this);
+ pAccContext = new SvxRectCtlAccessibleContext(this);
return pAccContext.get();
}
-RectPoint RectCtl::GetApproxRPFromPixPt( const css::awt::Point& r ) const
+RectPoint SvxRectCtl::GetApproxRPFromPixPt( const css::awt::Point& r ) const
{
return GetRPFromPoint( GetApproxLogPtFromPixPt( Point( r.X, r.Y ) ) );
}
-// CompletelyDisabled() added to have a disabled state for RectCtl
-void RectCtl::DoCompletelyDisable(bool bNew)
+// CompletelyDisabled() added to have a disabled state for SvxRectCtl
+void SvxRectCtl::DoCompletelyDisable(bool bNew)
{
mbCompleteDisable = bNew;
Invalidate();
@@ -187,9 +187,9 @@ void RectCtl::InitSettings(vcl::RenderContext& rRenderContext)
{
- // CompletelyDisabled() added to have a disabled state for RectCtl
+ // CompletelyDisabled() added to have a disabled state for SvxRectCtl
if(!IsCompletelyDisabled())
{
@@ -201,9 +201,9 @@ void RectCtl::MouseButtonDown(const MouseEvent& rMEvt)
{
- // CompletelyDisabled() added to have a disabled state for RectCtl
+ // CompletelyDisabled() added to have a disabled state for SvxRectCtl
if (IsCompletelyDisabled())
return false;
@@ -327,7 +327,7 @@ void RectCtl::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle&)
BitmapEx& rBitmap = GetRectBitmap();
- // CompletelyDisabled() added to have a disabled state for RectCtl
+ // CompletelyDisabled() added to have a disabled state for SvxRectCtl
if (IsCompletelyDisabled())
{
@@ -357,7 +357,7 @@ void RectCtl::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle&)
}
// draw active button, avoid center pos for angle
- // CompletelyDisabled() added to have a disabled state for RectCtl
+ // CompletelyDisabled() added to have a disabled state for SvxRectCtl
if (!IsCompletelyDisabled())
{